<?php

/**
 * @file
 * Contains \Drupal\styleswitcher\Form\StyleswitcherAdmin.
 */

namespace Drupal\styleswitcher\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Configure Styleswitcher settings.
 */
class StyleswitcherAdmin extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'styleswitcher_admin';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['styleswitcher.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $styles = styleswitcher_custom_styles();
    ksort($styles);

    $header = [t('Style'), ['data' => t('Operations'), 'colspan' => '2']];
    $rows = [];

    foreach ($styles as $name => $style) {
      $name_hyphenated = strtr($name, '_', '-');
      list(, $name_value) = explode('/', $name_hyphenated);

      $edit_link = Link::fromTextAndUrl(t('edit'), Url::fromRoute('styleswitcher.style_edit', ['style' => $name_value]))->toRenderable();
      $delete_link = Link::fromTextAndUrl(t('delete'), Url::fromRoute('styleswitcher.style_delete', ['style' => $name_value]))->toRenderable();
      // Do not allow to delete the blank style.
      $delete_link['#access'] = isset($style['path']);

      // Build the table row.
      $rows[] = [
        [
          'data' => [
            '#theme' => 'styleswitcher_admin_style_overview',
            '#style' => $style,
          ],
        ],
        ['data' => $edit_link],
        ['data' => $delete_link],
      ];
    }

    $form['styleswitcher_custom_styles'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    ];

    $form['enable_overlay'] = [
      '#type' => 'checkbox',
      '#title' => t('Enable overlay'),
      '#description' => t('Enable the overlay and fade when switching stylesheets.'),
      '#default_value' => $this->config('styleswitcher.settings')->get('enable_overlay'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('styleswitcher.settings');
    $config->set('enable_overlay', $form_state->getValue('enable_overlay'));
    $config->save();

    _styleswitcher_configuration_changed();

    parent::submitForm($form, $form_state);
  }

}
